"""
Simple cascading/nested scope/namespace manager

Obsolete

Use collections.ChainMap()
"""

__author__ = """Brendan Strejcek"""
__email__ = 'brendan@datagazing.com'
__version__ = '1.0.0'

# from .delegatum import Delegatum  # noqa F401
